![logo](logo/pytorch_logo.svg)

## Contents

### Basics

- **QuickStart** [[File](tutorials/01-basics/01-quickstart/main.py) | [Notebook](tutorials/01-basics/01-quickstart/main.ipynb)] - **QuickStart** gives general overview of **Basics** section.
- **Tensors** [[File](tutorials/01-basics/02-tensors/main.py) | [Notebook](tutorials/01-basics/02-tensors/main.ipynb)] - **Operations** on tensors, numpy arrays and casting them to tensor or vice versa.
- **Datasets and DataLoaders** [[File](tutorials/01-basics/03-dataset-dataloaders/main.py) | [Notebook](tutorials/01-basics/03-dataset-dataloaders/main.ipynb)] - Creating **datasets** and **dataloaders**.
- **Transforms** [[File](tutorials/01-basics/04-transforms/main.py) | [Notebook](tutorials/01-basics/04-transforms/main.ipynb)] - Torchvision's **augmentation** methods and using them together.
- **Build Neural Network** [[File](tutorials/01-basics/05-neural-network/main.py) | [Notebook](tutorials/01-basics/05-neural-network/main.ipynb)] - Building simple neural network from scratch.
- **Optimizers, Model Save and Load** [[File](tutorials/01-basics/06-optim-save-load/main.py) | [Notebook](tutorials/01-basics/06-optim-save-load/main.ipynb)] - Creating **optimizer**, **saving** trained model and **loading** for inference.


### Beginner

- [Autograd and Freeze weights](tutorials/02-beginner/01-autograd/main.py) - Autograd: **Automatic Differentiation**. 
- [Neural Networks](tutorials/02-beginner/02-neural-networks/main.py) - To look deep into **Neural Networks**.

### Intermediate

- [Convolutional Neural Network](tutorials/03-intermediate/01-convolutional-nn/main.py) - Classifying images of CIFAR10 using **CNNs**.
- [Residual Neural Network](tutorials/03-intermediate/02-deep-residual-nn/main.py) - Using **Residual Blocks** to build a CNN for image classification.
- [Recurrent Neural Network](tutorials/03-intermediate/03-recurrent-nn/main.py) - Image classification using **RNN** networks.
- [Long Short Term Memory](tutorials/03-intermediate/04-lstm-network/main.py) - MNIST digit classifier using **LSTM**.
- [Variational Auto Encoder](tutorials/03-intermediate/05-var-auto-encode/main.py) - Reconstructing MNIST data samples using **VAE**.

### Advanced

- [Adversarial Generative Network](https://github.com/yakhyo/DCGAN-pt) - Deep Convolutional **Generative Adversarial Network**.
- [Fast Neural Style Transfer](https://github.com/yakhyo/Fast-Neural-Style-Transfer) - Transferring image with different styles.
- [Super Resolution. Running it Using ONNX Runtime](tutorials/04-advanced/03-super-resolution-onnx/main.py) - **Inference** using **ONNX** Runtime.


<br>
<br>

_Updating..._

**References**

1. [https://github.com/pytorch/examples](https://github.com/pytorch/examples)
2. [https://www.deeplearningwizard.com](https://www.deeplearningwizard.com/deep_learning/intro/)
